<?php
/*
  Plugin Name: Embed OSM
  Plugin URI: http://midoriit.com/works/embed-osm.html
  Description: Embed OpenStreetMap on the page.
  Version: 0.4
  Author: Midori IT Office
  Author URI: http://midoriit.com/
  License: GPL3
*/

$embedosm = new EmbedOSM();

class EmbedOSM {

  public function __construct() {
      register_activation_hook(__FILE__, array(&$this,'embed_osm_activate'));
      register_uninstall_hook(__FILE__, 'EmbedOSM::embed_osm_uninstall');
      add_shortcode('embed_osm', array(&$this, 'embed_osm_handler'));
      add_action('admin_menu', array(&$this, 'embed_osm_menu'));
  }

  public function embed_osm_activate() {
    add_option('embed_osm_width', '400');
    add_option('embed_osm_height', '300');
  }

  public static function embed_osm_uninstall() {
    delete_option('embed_osm_width');
    delete_option('embed_osm_height');
  }

  public function embed_osm_handler( $atts ) {
    $width = get_option('embed_osm_width');
    $height = get_option('embed_osm_height');
    $uniq = uniqid("",1);

    extract( shortcode_atts( array(
      'lon' => '0',
      'lat' => '0',
      'zoom' => '1'),
        $atts ) );

    return 
'  <div id="mapdiv'.$uniq.'" style="width:'.$width.'px; height:'.$height.'px;"></div>
  <script type="text/javascript" src="'.plugins_url().'/embed-osm/openlayers/OpenLayers.js"></script>
  <script type="text/javascript">
    var map = new OpenLayers.Map("mapdiv'.$uniq.'");
    map.addLayer(new OpenLayers.Layer.OSM());
    var lonLat = new OpenLayers.LonLat('.$lon.' , '.$lat.').transform(
      new OpenLayers.Projection("EPSG:4326"),
      map.getProjectionObject() );
    map.setCenter(lonLat, '.$zoom.');
    var markers = new OpenLayers.Layer.Markers("Markers");
    map.addLayer(markers);
    var marker = new OpenLayers.Marker(lonLat)
    markers.addMarker(marker);
  </script>
  <small>
    <a href="http://www.openstreetmap.org/?mlat='.$lat.'&amp;mlon='.$lon.'#map='.$zoom.'/'.$lat.'/'.$lon.'" target="_blank">大きな地図を表示</a>
  </small>';
  }

  function embed_osm_menu() {
    add_options_page('Embed OSM Options', 'Embed OSM', 'manage_options',
      'embed_osm', array(&$this, 'embed_osm_options'));
  }

  function embed_osm_options() {
    if ( !current_user_can( 'manage_options' ) )  {
      wp_die( __( 'insufficient permissions.' ) );
    }

    if (isset($_POST['update_option'])) {
      check_admin_referer('embed_osm_options');
      $width = $_POST['embed_osm_width'];
      if(is_numeric($width)){
        update_option('embed_osm_width', $width);
      }
      $height = $_POST['embed_osm_height'];
      if(is_numeric($height)){
        update_option('embed_osm_height', $height);
      }
    }
    $width = get_option('embed_osm_width');
    $height = get_option('embed_osm_height');
    echo '<div><h2>Embed OSM Options</h2>';
    echo '<form name="form" method="post" action="">';
    wp_nonce_field('embed_osm_options');
    echo '<table class="form-table"><tbody>';
    echo '<tr><td>Map Width</td>';
    echo '<td><input type="text" name="embed_osm_width" value="'.$width.'" size="20"></td></tr>';
    echo '<tr><td>Map Height</td>';
    echo '<td><input type="text" name="embed_osm_height" value="'.$height.'" size="20"></td></tr>';
    echo '</tbody></table>';
    echo '<input type="submit" name="update_option" class="button button-primary" value="'.esc_attr__('Save Changes').'" />';
    echo '</form>';
    echo '</div>';
  }
}
?>
